pub struct ConcurrentConversionManager { /* private fields */ }Expand description
Thread-safe concurrent conversion manager
Implementations
Sourceimpl ConcurrentConversionManager
impl ConcurrentConversionManager
Sourcepub fn new(
max_concurrent_operations: usize,
max_cached_models: usize,
config: ConversionConfig,
) -> Self
pub fn new( max_concurrent_operations: usize, max_cached_models: usize, config: ConversionConfig, ) -> Self
Create new concurrent conversion manager with specified concurrency limits
Sourcepub async fn convert_with_concurrency_control(
&self,
request: ConversionRequest,
) -> Result<ConversionResult>
pub async fn convert_with_concurrency_control( &self, request: ConversionRequest, ) -> Result<ConversionResult>
Process conversion request with thread-safe concurrency control and metrics tracking
Sourcepub async fn get_metrics(&self) -> ConcurrentConversionMetrics
pub async fn get_metrics(&self) -> ConcurrentConversionMetrics
Get current conversion metrics snapshot
Sourcepub async fn get_operation_state(&self) -> OperationState
pub async fn get_operation_state(&self) -> OperationState
Get current operation state snapshot with active operations
Sourcepub async fn update_config(&self, new_config: ConversionConfig) -> Result<()>
pub async fn update_config(&self, new_config: ConversionConfig) -> Result<()>
Update configuration with thread-safe write lock
Sourcepub async fn get_config(&self) -> ConversionConfig
pub async fn get_config(&self) -> ConversionConfig
Get current configuration snapshot with thread-safe read lock
Sourcepub async fn health_check(&self) -> HashMap<String, String>
pub async fn health_check(&self) -> HashMap<String, String>
Perform health check and return status metrics for monitoring